@@ -7,12 +7,12 @@
  ************************************************************************
  **
  **   Copyright (c):  2004      by André Somers
- **                   2007-2010 by Axel Pauli
+ **                   2007-2011 by Axel Pauli
  **
  **   This file is distributed under the terms of the General Public
  **   License. See the file COPYING for more information.
  **
- **   $Id: generalconfig.cpp 4426 2010-11-22 23:00:47Z axel $
+ **   $Id: generalconfig.cpp 4597 2011-04-28 18:55:45Z axel $
  **
  ***********************************************************************/
 
@@ -31,6 +31,7 @@ using namespace std;
 #include "altitude.h"
 #include "distance.h"
 #include "time_cu.h"
+#include "preflightwaypointpage.h"
 
 #ifdef MAEMO
 #include "maemostyle.h"
@@ -74,6 +75,7 @@ void GeneralConfig::load()
   // cumulus main data
   beginGroup("Main");
   _installRoot = value("InstallRoot", "./").toString();
+  _builtDate = value("BuiltDate", __DATE__).toString();
   endGroup();
 
   // Main window properties
@@ -111,6 +113,7 @@ void GeneralConfig::load()
   _lastAirspaceUrl      = value("LastAirspaceUrl", "").toString();
   _forceDrawing         = value("forceLowAirspaceDrawing", true ).toBool();
   _forceDrawingDistance = value("forceLowAirspaceDrawingDistance", 150.0).toDouble();
+  _airspaceFileList     = value("FileList", QStringList(QString("All"))).toStringList();
 
 #ifndef MAEMO
   _airspaceLineWidth = value( "AirSpaceLineWidth", 5 ).toInt();
@@ -199,20 +202,23 @@ void GeneralConfig::load()
   _disclaimerVersion = value( "Disclaimer", 0).toInt();
   _surname           = value("SurName", "").toString();
   _language          = value("Language", "en").toString();
+  _homeCountryCode   = value("HomeCountryCode", "").toString();
   _userDataDirectory = value("UserDataDir", "").toString();
   endGroup();
 
   // Preflight settings
   beginGroup("Preflight Data");
   _safetyAltitude.setMeters(  value( "Arrival Altitude", 200.0 ).toDouble() );
-  _qnh                 = value( "QNH", 1013 ).toInt();
-  _bRecordInterval     = value( "B-RecordLoggerInterval", 10 ).toInt();
-  _kRecordInterval     = value( "K-RecordLoggerInterval", 0 ).toInt();
-  _loggerAutostartMode = value( "LoggerAutostartMode", false ).toBool();
-  _tas                 = value( "TAS", 100 ).toInt();
-  _windDirection       = value( "WindDirection", 0 ).toInt();
-  _windSpeed           = value( "WindSpeed", 0 ).toInt();
-  _currentTask         = value( "CurrentTask", "").toString();
+  _arrivalAltitudeDisplay = (enum ArrivalAltitudeDisplay) value( "ArrivalAltitudeDisplay",
+                                    GeneralConfig::landingTarget ).toInt();
+  _qnh                    = value( "QNH", 1013 ).toInt();
+  _bRecordInterval        = value( "B-RecordLoggerInterval", 10 ).toInt();
+  _kRecordInterval        = value( "K-RecordLoggerInterval", 0 ).toInt();
+  _loggerAutostartMode    = value( "LoggerAutostartMode", false ).toBool();
+  _tas                    = value( "TAS", 100 ).toInt();
+  _windDirection          = value( "WindDirection", 0 ).toInt();
+  _windSpeed              = value( "WindSpeed", 0 ).toInt();
+  _currentTask            = value( "CurrentTask", "").toString();
   endGroup();
 
   // Task scheme settings for cylinder-sector and nearest-touched
@@ -266,9 +272,9 @@ void GeneralConfig::load()
   _mapShowWaypointLabels          = value( "ShowWaypointLabels", false ).toBool();
   _mapShowLabelsExtraInfo         = value( "ShowLabelsExtraInfo", false ).toBool();
 
-  _wayPointScaleBorders[wayPoint::Low]    = value( "WpScaleBorderLow", 125 ).toInt();
-  _wayPointScaleBorders[wayPoint::Normal] = value( "WpScaleBorderNormal", 250 ).toInt();
-  _wayPointScaleBorders[wayPoint::High]   = value( "WpScaleBorderHigh", 500 ).toInt();
+  _wayPointScaleBorders[Waypoint::Low]    = value( "WpScaleBorderLow", 125 ).toInt();
+  _wayPointScaleBorders[Waypoint::Normal] = value( "WpScaleBorderNormal", 250 ).toInt();
+  _wayPointScaleBorders[Waypoint::High]   = value( "WpScaleBorderHigh", 500 ).toInt();
   endGroup();
 
   beginGroup("Map Data");
@@ -324,7 +330,12 @@ void GeneralConfig::load()
   endGroup();
 
   beginGroup("Waypoint Data");
-  _waypointFile = value( "WaypointFile", "cumulus.kwp" ).toString();
+  _waypointBinaryFileName    = value( "BinaryDefaultFileName", "cumulus.kwp" ).toString();
+  _waypointXmlFileName       = value( "XmlDefaultFileName", "cumulus.kflogwp" ).toString();
+  _waypointFileFormat        = (enum WpFileFormat) value( "FileFormat", Binary ).toInt();
+  _waypointPriority          = value( "StoragePriority", 0 ).toInt();
+  _waypointCenterReference   = value( "CenterReference", PreFlightWaypointPage::Home ).toInt();
+  _waypointAirfieldReference = value( "AirfieldReference", "" ).toString();
   endGroup();
 
   beginGroup("Variometer");
@@ -440,6 +451,7 @@ void GeneralConfig::save()
   // cumulus main data
   beginGroup("Main");
   setValue("InstallRoot", _installRoot );
+  setValue("BuiltDate", _builtDate);
   endGroup();
 
   // Main window properties
@@ -465,7 +477,8 @@ void GeneralConfig::save()
   setValue("LastAirspaceUrl", _lastAirspaceUrl);
   setValue("forceLowAirspaceDrawing", _forceDrawing);
   setValue("forceLowAirspaceDrawingDistance", _forceDrawingDistance.getMeters());
-  setValue( "AirSpaceLineWidth", _airspaceLineWidth );
+  setValue("AirSpaceLineWidth", _airspaceLineWidth);
+  setValue("FileList", _airspaceFileList);
 
   // Airspace warning types
   setValue("checkAirspaceA", _airspaceDrawingEnabled[BaseMapElement::AirA]);
@@ -541,6 +554,7 @@ void GeneralConfig::save()
   setValue("Disclaimer", _disclaimerVersion);
   setValue("SurName", _surname);
   setValue("Language", _language);
+  setValue("HomeCountryCode", _homeCountryCode);
   setValue( "UserDataDir", _userDataDirectory);
   setValue("Proxy", _proxy);
   endGroup();
@@ -548,6 +562,7 @@ void GeneralConfig::save()
   // Preflight data
   beginGroup("Preflight Data");
   setValue( "Arrival Altitude", _safetyAltitude.getMeters() );
+  setValue( "ArrivalAltitudeDisplay",  _arrivalAltitudeDisplay );
   setValue( "QNH", _qnh );
   setValue( "B-RecordLoggerInterval", _bRecordInterval );
   setValue( "K-RecordLoggerInterval", _kRecordInterval );
@@ -602,9 +617,9 @@ void GeneralConfig::save()
   setValue( "ShowAirfieldLabels", _mapShowAirfieldLabels );
   setValue( "ShowTaskPointLabels", _mapShowTaskPointLabels );
   setValue( "ShowOutLandingLabels", _mapShowOutLandingLabels );
-  setValue( "WpScaleBorderLow", _wayPointScaleBorders[wayPoint::Low] );
-  setValue( "WpScaleBorderNormal", _wayPointScaleBorders[wayPoint::Normal] );
-  setValue( "WpScaleBorderHigh", _wayPointScaleBorders[wayPoint::High] );
+  setValue( "WpScaleBorderLow", _wayPointScaleBorders[Waypoint::Low] );
+  setValue( "WpScaleBorderNormal", _wayPointScaleBorders[Waypoint::Normal] );
+  setValue( "WpScaleBorderHigh", _wayPointScaleBorders[Waypoint::High] );
   endGroup();
 
   beginGroup("Map Data");
@@ -658,8 +673,13 @@ void GeneralConfig::save()
   endGroup();
 
   beginGroup("Waypoint Data");
+  setValue( "BinaryDefaultFileName", _waypointBinaryFileName );
+  setValue( "XmlDefaultFileName", _waypointXmlFileName );
+  setValue( "FileFormat", _waypointFileFormat );
+  setValue( "StoragePriority", _waypointPriority );
+  setValue( "CenterReference", _waypointCenterReference );
+  setValue( "AirfieldReference", _waypointAirfieldReference );
   endGroup();
-  setValue( "WaypointFile", _waypointFile );
 
   beginGroup("Variometer");
   setValue( "IntegrationTime", _varioIntegrationTime );
@@ -1162,20 +1182,6 @@ void GeneralConfig::setManualNavModeAltitude(const int newValue)
 }
 
 
-/** Gets the waypoint file name with path */
-QString &GeneralConfig::getWaypointFile()
-{
-  return _waypointFile;
-}
-
-
-/** Sets the waypoint file name with path */
-void GeneralConfig::setWaypointFile( const QString newValue )
-{
-  _waypointFile = newValue;
-}
-
-
 /** Gets the unit for altitude*/
 int GeneralConfig::getUnitAlt() const
 {
@@ -1295,35 +1301,43 @@ void GeneralConfig::setAirspaceFillingLateral(Airspace::ConflictType nearness, i
 /* Load a pixmap from the cache. If not contained there, insert it. */
 QPixmap GeneralConfig::loadPixmap( const QString& pixmapName )
 {
+  static bool firstCall = true;
+  static QPixmap smallEmptyPixmap( 16, 16 );
+  static QPixmap emptyPixmap( 32, 32 );
+
+  if( firstCall )
+    {
+      firstCall = false;
+      smallEmptyPixmap.fill( Qt::transparent );
+      emptyPixmap.fill( Qt::transparent );
+    }
+
   // determine absolute path to pixmap directory
   QString path( _installRoot + "/icons/" + pixmapName );
-  QString emptyPath( _installRoot + "/icons/empty.xpm" );
 
   QPixmap pm;
 
-  if( !QPixmapCache::find( path, pm ) )
+  if( QPixmapCache::find( path, pm ) )
     {
-      if( ! pm.load( path ) )
-        {
-          qWarning( "Could not load Pixmap file '%s'. Maybe it was not installed?",
-                    path.toLatin1().data() );
-        }
-
-      QPixmapCache::insert( path, pm );
-    }
-  else if( !QPixmapCache::find( emptyPath, pm ) )
-    {
-      if( ! pm.load( path ) )
-        {
-          qWarning( "Could not load fallback Pixmap file '%s'. Maybe it was not installed?",
-                    emptyPath.toLatin1().data() );
-        }
-
-      QPixmapCache::insert( path, pm );
+      return pm;
     }
 
+  if( pm.load( path ) )
+    {
+      QPixmapCache::insert( path, pm );
+      return pm;
+    }
 
-  return pm;
+  qWarning( "Could not load Pixmap file '%s'. Maybe it was not installed?",
+             path.toLatin1().data() );
+
+  // Return an empty transparent pixmap as default
+  if( pixmapName.startsWith( "small/") )
+    {
+      return smallEmptyPixmap;
+    }
+
+  return emptyPixmap;
 }
 
 /**
@@ -1710,15 +1724,15 @@ void GeneralConfig::printIsoColorDefinitions()
 #endif
 
 /** Gets waypoint scale border. */
-int GeneralConfig::getWaypointScaleBorder( const wayPoint::Importance importance) const
+int GeneralConfig::getWaypointScaleBorder( const Waypoint::Priority importance) const
 {
   switch( importance )
   {
-    case wayPoint::Low:
-    case wayPoint::Normal:
-    case wayPoint::High:
+    case Waypoint::Low:
+    case Waypoint::Normal:
+    case Waypoint::High:
 
-      // qDebug("Importance=%d, value=%d", importance, _wayPointScaleBorders[importance] );
+      // qDebug("Priority=%d, value=%d", priority, _wayPointScaleBorders[priority] );
 
       return _wayPointScaleBorders[importance];
       break;
@@ -1730,14 +1744,14 @@ int GeneralConfig::getWaypointScaleBorder( const wayPoint::Importance importance
 }
 
 /** Sets waypoint scale border. */
-void GeneralConfig::setWaypointScaleBorder( const wayPoint::Importance importance,
+void GeneralConfig::setWaypointScaleBorder( const Waypoint::Priority importance,
                                             const int newScale )
 {
   switch( importance )
   {
-    case wayPoint::Low:
-    case wayPoint::Normal:
-    case wayPoint::High:
+    case Waypoint::Low:
+    case Waypoint::Normal:
+    case Waypoint::High:
       _wayPointScaleBorders[importance] = newScale;
       break;
 
