@@ -7,25 +7,30 @@
 ************************************************************************
 **
 **   Copyright (c):  2004      by André Somers
-**                   2007-2010 by Axel Pauli
+**                   2007-2011 by Axel Pauli
 **
 **   This file is distributed under the terms of the General Public
 **   License. See the file COPYING for more information.
 **
-**   $Id: generalconfig.h 4396 2010-11-11 21:20:47Z axel $
+**   $Id: generalconfig.h 4597 2011-04-28 18:55:45Z axel $
 **
 ***********************************************************************/
 
 /**
+ * \class GeneralConfig
+ *
  * \author André Somers, Axel Pauli
  *
- * \brief Configuration encapsulation class
+ * \brief Configuration manager class
  *
  * This class is used to store and retrieve all kinds of
  * configuration options. This class is a singleton class. Use the
  * static instance method to get a reference to the instance.
  *
-*/
+ * \date 2004-2011
+ *
+ * \version $Id: generalconfig.h 4597 2011-04-28 18:55:45Z axel $
+ */
 
 #ifndef GENERAL_CONFIG_H
 #define GENERAL_CONFIG_H
@@ -70,28 +75,37 @@ class GeneralConfig : protected QSettings
 {
  public:
 
-  enum UseInMode {
-    never,
-    standstill,
-    circling,
-    cruising,
-    wave,
-    always
+  enum UseInMode
+  {
+    never, standstill, circling, cruising, wave, always
   };
 
   // CS Task scheme data
-  enum ActiveCSTaskScheme {
-    Cylinder=0,
-    Sector=1
+  enum ActiveCSTaskScheme
+  {
+    Cylinder = 0, Sector = 1
   };
 
   // CS Task scheme data
-  enum ActiveNTTaskScheme {
-    Nearst=0,
-    Touched=1
+  enum ActiveNTTaskScheme
+  {
+    Nearst = 0, Touched = 1
+  };
+
+  /** Waypoint file storage formats. */
+  enum WpFileFormat
+  {
+    Binary = 0, XML = 1
+  };
+
+  /** Arrival altitude display selection, if a flight task is active. */
+  enum ArrivalAltitudeDisplay
+  {
+    landingTarget = 0, nextTarget = 1
   };
 
  private:
+
   /**
    * Constructor is private because this is a singleton class.
    * The relevant settings are loaded on construction.
@@ -136,18 +150,30 @@ class GeneralConfig : protected QSettings
   // properties get/set methods
   //---------------------------
 
-  /** gets the installation root of cumulus */
+  /** gets the installation root of Cumulus */
   QString &getInstallRoot()
     {
       return _installRoot;
     };
 
-  /** sets the installation root of cumulus */
+  /** sets the installation root of Cumulus */
   void setInstallRoot( QString &newRoot )
   {
     _installRoot = newRoot;
   };
 
+  /** gets the built date of Cumulus */
+  QString &getBuiltDate()
+    {
+      return _builtDate;
+    };
+
+  /** sets the built date of Cumulus */
+  void setBuiltDate( QString newBuiltDate )
+  {
+    _builtDate = newBuiltDate;
+  };
+
   /** gets the user data directory where waypoint file, task file,
       glider.pol, logger files are stored */
   QString getUserDataDirectory();
@@ -174,12 +200,13 @@ class GeneralConfig : protected QSettings
   void setOurGuiStyle();
 
   /**
-   * @returns requested pixmap
+   * @param pixmapName The pixmap to be loaded.
+   * @return The requested pixmap.
    */
   QPixmap loadPixmap( const QString& pixmapName );
 
   /**
-   * @removes a pixmap from the global cache
+   * @param pixmapName Removes the pixmap from the global cache.
    */
   void removePixmap( const QString& pixmapName );
 
@@ -531,12 +558,15 @@ class GeneralConfig : protected QSettings
 
   /**
    * @return True if drawing is enabled for the given base map type.
-   * @param objectType The type of object (defined in @ref BaseMapElement) to query
+   * @param type The type of object (defined in @ref BaseMapElement) to query.
    */
   bool getAirspaceDrawingEnabled (BaseMapElement::objectType type) const;
 
   /**
    * Enables or disables the airspace drawing for this type of airspace
+   *
+   * \param type The type of object (defined in @ref BaseMapElement) to set.
+   * \param enable A flag to enable/disable drawing of airspace element.
    */
   void setAirspaceDrawingEnabled (BaseMapElement::objectType type, bool enable=true)
   {
@@ -830,6 +860,17 @@ class GeneralConfig : protected QSettings
     _currentTask = newValue;
   };
 
+  /** Gets the homesite country code */
+  QString &getHomeCountryCode()
+    {
+      return _homeCountryCode;
+    };
+  /** Sets the homesite country code */
+  void setHomeCountryCode( const QString newValue )
+  {
+    _homeCountryCode = newValue;
+  };
+
   /** gets homesite Latitude */
   int getHomeLat() const
   {
@@ -1555,10 +1596,71 @@ class GeneralConfig : protected QSettings
   /** sets manual navigation mode altitude */
   void setManualNavModeAltitude(const int newValue);
 
-  /** Gets the waypoint file name with path */
-  QString &getWaypointFile();
-  /** Sets the waypoint file name with path */
-  void setWaypointFile( const QString newValue );
+  /** Gets the default binary waypoint file name with path. */
+  QString &getBinaryWaypointFileName()
+  {
+    return _waypointBinaryFileName;
+  };
+  /** Sets the default binary waypoint file name with path. */
+  void setBinaryWaypointFileName( const QString newValue )
+  {
+    _waypointBinaryFileName = newValue;
+  };
+
+  /** Gets the default XML waypoint file name with path. */
+  QString &getXmlWaypointFileName()
+  {
+    return _waypointXmlFileName;
+  };
+  /** Sets the default XML waypoint file name with path. */
+  void setXmlWaypointFileName( const QString newValue )
+  {
+    _waypointXmlFileName = newValue;
+  };
+
+  /** Gets the waypoint file format */
+  enum WpFileFormat getWaypointFileFormat() const
+  {
+    return _waypointFileFormat;
+  };
+  /** Sets the waypoint file format */
+  void setWaypointFileFormat(const enum WpFileFormat newValue)
+  {
+    _waypointFileFormat = newValue;
+  };
+
+  /** Gets the waypoint priority */
+  int getWaypointPriority() const
+  {
+    return _waypointPriority;
+  };
+  /** Sets the waypoint priority */
+  void setWaypointPriority(const int newValue)
+  {
+    _waypointPriority = newValue;
+  };
+
+  /** Gets the waypoint import center reference. */
+  int getWaypointCenterReference() const
+  {
+    return _waypointCenterReference;
+  };
+  /** Sets the waypoint import center reference. */
+  void setWaypointCenterReference(const int newValue)
+  {
+    _waypointCenterReference = newValue;
+  };
+
+  /** Gets the waypoint import airfield reference. */
+  QString &getWaypointAirfieldReference()
+  {
+    return _waypointAirfieldReference;
+  };
+  /** Sets the waypoint import airfield reference. */
+  void setWaypointAirfieldReference( const QString newValue )
+  {
+    _waypointAirfieldReference = newValue;
+  };
 
   /** Gets the unit for altitude*/
   int getUnitAlt() const;
@@ -1612,6 +1714,18 @@ class GeneralConfig : protected QSettings
     _airspaceLineWidth = newValue;
   };
 
+  /** Gets the airspace file list to be loaded. */
+  QStringList& getAirspaceFileList()
+  {
+    return _airspaceFileList;
+  };
+
+  /** Sets the airspace file list to be loaded. */
+  void setAirspaceFileList( const QStringList& newValue )
+  {
+    _airspaceFileList = newValue;
+  };
+
   /**
    * Get whether airspace filling is enabled at all
    */
@@ -1679,6 +1793,18 @@ class GeneralConfig : protected QSettings
    */
   void setDrawTrail(UseInMode draw) {_drawTrail = draw;};
 
+  /** Gets the arrival altitude display selection. */
+  enum ArrivalAltitudeDisplay getArrivalAltitudeDisplay() const
+  {
+    return _arrivalAltitudeDisplay;
+  };
+
+  /** Sets the arrival altitude display selection. */
+  void setArrivalAltitudeDisplay( const enum ArrivalAltitudeDisplay newValue )
+  {
+    _arrivalAltitudeDisplay = newValue;
+  };
+
   /** Gets the active cs task scheme */
   enum ActiveCSTaskScheme getActiveCSTaskScheme() const
   {
@@ -1836,10 +1962,10 @@ class GeneralConfig : protected QSettings
   };
 
   /** Gets waypoint scale border. */
-  int getWaypointScaleBorder( const wayPoint::Importance importance) const;
+  int getWaypointScaleBorder( const Waypoint::Priority importance) const;
 
   /** Sets waypoint scale border. */
-  void setWaypointScaleBorder( const wayPoint::Importance importance,
+  void setWaypointScaleBorder( const Waypoint::Priority importance,
                                const int newScale );
 
   /** Gets the Flarm alias file name. */
@@ -1858,6 +1984,9 @@ class GeneralConfig : protected QSettings
   // Root path of cumulus installation
   QString _installRoot;
 
+  // Date of built
+  QString _builtDate;
+
   // Main window size
   QSize _windowSize;
 
@@ -1940,6 +2069,9 @@ class GeneralConfig : protected QSettings
   // last used airspace url
   QString _lastAirspaceUrl;
 
+  // Airspace files to be loaded
+  QStringList _airspaceFileList;
+
   // disclaimer version
   int _disclaimerVersion;
   Altitude _safetyAltitude;
@@ -1976,6 +2108,8 @@ class GeneralConfig : protected QSettings
   // current selected task
   QString _currentTask;
 
+  // Homesite country code
+  QString _homeCountryCode;
   // Homesite elevation
   Distance _homeElevation;
   // Homesite coordinates
@@ -2154,8 +2288,23 @@ class GeneralConfig : protected QSettings
   // manual navigation mode altitude
   int _manualNavModeAltitude;
 
-  // Waypoint data file name
-  QString _waypointFile;
+  // Default binary waypoint file name
+  QString _waypointBinaryFileName;
+
+  // Default XML waypoint file name
+  QString _waypointXmlFileName;
+
+  /** Waypoint file format. 0=binary, 1=xml */
+  enum WpFileFormat _waypointFileFormat;
+
+  /** Waypoint import storage priority. */
+  int _waypointPriority;
+
+  /** Waypoint import center reference */
+  int _waypointCenterReference;
+
+  /** Waypoint import airfield reference. */
+  QString _waypointAirfieldReference;
 
   /** Flarm alias file name. */
   QString _flarmAliasFileName;
@@ -2182,6 +2331,9 @@ class GeneralConfig : protected QSettings
   enum ActiveCSTaskScheme _taskActiveCSScheme;
   enum ActiveNTTaskScheme _taskActiveNTScheme;
 
+  // arrival altitude display selection
+  enum ArrivalAltitudeDisplay _arrivalAltitudeDisplay;
+
   // Task shape alpha transparency
   int _taskShapeAlpha;
 
@@ -2197,7 +2349,7 @@ class GeneralConfig : protected QSettings
   bool _taskDrawShape;
   bool _taskFillShape;
 
-  /** Waypoint drawing scale borders. Addressed by waypoint importance
+  /** Waypoint drawing scale borders. Addressed by waypoint priority
    *  (Low=0, Normal=1, High=2). It contains the scale borders defined
    *  user.
    */
